@@ -17,6 +17,10 @@ impl Call {
   ) -> Box<Self> {
     Box::new(Self{ function_idx, parameters })
   }
+
+  pub fn new_stacked(function_idx: u32) -> Box<Self> {
+    Box::new(Self{ function_idx, parameters: Vec::new() })
+  }
 }
 
 impl Compilable for Call {
@@ -35,7 +39,7 @@ pub struct CallIndirect {
   type_idx:     u32,
   table_idx:    u32,
   parameters:   Vec<Box<dyn Instruction>>,
-  function_idx: Box<dyn Instruction>,
+  function_idx: Option<Box<dyn Instruction>>,
 }
 
 impl CallIndirect {
@@ -45,16 +49,35 @@ impl CallIndirect {
     parameters:   Vec<Box<dyn Instruction>>,
     function_idx: Box<dyn Instruction>,
   ) -> Box<Self> {
-    Box::new(Self{ type_idx, table_idx, parameters, function_idx })
+    Box::new(Self{
+      type_idx,
+      table_idx,
+      parameters,
+      function_idx: Some(function_idx),
+    })
+  }
+
+  pub fn new_stacked(
+    type_idx:     u32,
+    table_idx:    u32,
+  ) -> Box<Self> {
+    Box::new(Self{
+      type_idx,
+      table_idx,
+      parameters: Vec::new(),
+      function_idx: None,
+    })
   }
 }
 
 impl Compilable for CallIndirect {
   fn compile(&self, buf: &mut Vec<u8>) {
+    if let Some(function_idx) = &self.function_idx {
+      function_idx.compile(buf);
+    }
     for parameter in self.parameters.iter() {
       parameter.compile(buf);
     }
-    self.function_idx.compile(buf);
     buf.push(0x11);
     buf.extend(&from_u32(self.type_idx));
     buf.extend(&from_u32(self.table_idx));
